---
name: Security Vulnerability
about: Report security vulnerabilities
---

**Do not submit security vulnerabilities as issues**.

Create a [new Security Advisory](https://github.com/pytest-dev/pytest/security/advisories/new) instead.
